compute_key

Function compute_key 

pub fn compute_key(
    repo: &GitRepo,
    config_path: Option<&Path>,
    overrides: &[String],
) -> String
Compute cache key: SHA1 hex of (refs snapshot + HEAD + config file content + overrideconfig).

Corresponds to the four components of GitVersionCacheKeyFactory (gitSystemHash, repositorySnapshotHash, configFileHash, overrideConfigHash). The GitVersion binary version is intentionally not included in the key, so the cache is reused as long as the repository and config are unchanged (use --no-cache during development).