pub struct IgnoreConfig {
pub commits_before: Option<String>,
pub sha: Vec<String>,
pub paths: Vec<String>,
}Expand description
Commit-ignore configuration. ignore key.
Fields
commits_before: Option<String>sha: Vec<String>paths: Vec<String>Exclude commits that only touch files under these paths from version calculation. A commit is excluded only when all its changed files fall under the ignored paths.