Module files

Module files 

File output: AssemblyInfo, project files, Wix.

Corresponds to the original GitVersion.Output/AssemblyInfo/* and WixUpdater/*.

Functions

update_assembly_info
Update AssemblyInfo files (creates them when ensure is true and they are missing).
update_package_files
Update the version field in package manifests for various languages.
update_project_files
Update version elements in .csproj / .vbproj / .fsproj files.
write_wix
Generate the WiX version file (GitVersion_WixVersion.wxi).