update_assembly_info

Function update_assembly_info 

pub fn update_assembly_info(
    vars: &VersionVariables,
    work_dir: &Path,
    files: &[String],
    ensure: bool,
) -> Result<Vec<PathBuf>>
Update AssemblyInfo files (creates them when ensure is true and they are missing).

When files is empty, searches the working directory recursively for AssemblyInfo.{cs,vb,fs}.