pub fn show_variable(vars: &VersionVariables, name: &str) -> Result<String>Expand description
Output a single variable value. Returns an error if the variable does not exist.
pub fn show_variable(vars: &VersionVariables, name: &str) -> Result<String>Output a single variable value. Returns an error if the variable does not exist.