pub fn prepare(opts: &DynamicRepoOptions) -> Result<PathBuf>Expand description
Clone a remote repository (always fresh) and check out the target branch/commit, then return the path to the working tree.
pub fn prepare(opts: &DynamicRepoOptions) -> Result<PathBuf>Clone a remote repository (always fresh) and check out the target branch/commit, then return the path to the working tree.