EffectiveConfiguration

Struct EffectiveConfiguration 

pub struct EffectiveConfiguration {
Show 33 fields pub branch_key: String, pub deployment_mode: DeploymentMode, pub label: String, pub increment: IncrementStrategy, pub regex: Option<String>, pub prevent_increment_of_merged_branch: bool, pub prevent_increment_when_branch_merged: bool, pub prevent_increment_when_current_commit_tagged: bool, pub track_merge_target: bool, pub track_merge_message: bool, pub tracks_release_branches: bool, pub is_release_branch: bool, pub is_main_branch: bool, pub pre_release_weight: i64, pub tag_pre_release_weight: i64, pub commit_message_incrementing: CommitMessageIncrementMode, pub major_bump_message: String, pub minor_bump_message: String, pub patch_bump_message: String, pub no_bump_message: String, pub tag_prefix: String, pub version_in_branch_pattern: String, pub next_version: Option<String>, pub semantic_version_format: SemanticVersionFormat, pub commit_date_format: String, pub assembly_versioning_scheme: VersioningScheme, pub assembly_file_versioning_scheme: VersioningScheme, pub assembly_informational_format: String, pub assembly_versioning_format: Option<String>, pub assembly_file_versioning_format: Option<String>, pub merge_message_formats: BTreeMap<String, String>, pub source_branches: Vec<String>, pub label_number_pattern: String,
}
All configuration values flattened to those effective for a given branch.

Fields

branch_key: Stringdeployment_mode: DeploymentModelabel: Stringincrement: IncrementStrategyregex: Option<String>prevent_increment_of_merged_branch: boolprevent_increment_when_branch_merged: boolprevent_increment_when_current_commit_tagged: booltrack_merge_target: booltrack_merge_message: booltracks_release_branches: boolis_release_branch: boolis_main_branch: boolpre_release_weight: i64tag_pre_release_weight: i64commit_message_incrementing: CommitMessageIncrementModemajor_bump_message: Stringminor_bump_message: Stringpatch_bump_message: Stringno_bump_message: Stringtag_prefix: Stringversion_in_branch_pattern: Stringnext_version: Option<String>semantic_version_format: SemanticVersionFormatcommit_date_format: Stringassembly_versioning_scheme: VersioningSchemeassembly_file_versioning_scheme: VersioningSchemeassembly_informational_format: Stringassembly_versioning_format: Option<String>assembly_file_versioning_format: Option<String>merge_message_formats: BTreeMap<String, String>source_branches: Vec<String>label_number_pattern: String

Regex for extracting a number from the pre-release label.

Implementations

Source

impl EffectiveConfiguration

pub fn resolve(config: &GitVersionConfiguration, branch_name: &str) -> Self

Merge the global configuration with the matched branch configuration to produce the effective configuration.