locate

Function locate 

pub fn locate(dir: &Path, repo_root: Option<&Path>) -> Option<PathBuf>
Search for a configuration file in dir and repo_root.

Each directory’s entries are matched against CANDIDATES case-insensitively, so the canonical names are found regardless of spelling and regardless of whether the filesystem is case-sensitive (e.g. .gitversion.yml on Linux).