pub fn update_assembly_info(
vars: &VersionVariables,
work_dir: &Path,
files: &[String],
ensure: bool,
) -> Result<Vec<PathBuf>>Expand description
Update AssemblyInfo files (creates them when ensure is true and they are missing).
When files is empty, searches the working directory recursively for AssemblyInfo.{cs,vb,fs}.