Ratatui-based interactive TUI.
Goes beyond a simple viewer to offer exploration of computed results and operations that affect the actual version (tag/branch creation, next-version override, cache clearing, dynamic clone, per-branch recomputation).
Functions
- run
- Launch the TUI. Accepts a repository and configuration and runs interactively.